#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# HttpOperation
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################


# Built-in/Generic Imports
import os
import sys
import json
import urllib3
import ssl

# Own modules
from abstract import Base
from enums import MESSAGE_TYPE


class HttpOperation3(Base):
    _url = ""
    _response = None

    def __init__(self, url=None):
        Base.__init__(self)
        self._url = url

    def url(self):
        if self._url == None or not str(self._url).strip():
            return None
        else:
            return self._url

    def request(self, url=None, http_method="GET"):
        request_url = None
        if url is not None:
            request_url = str(url)
        else:
            request_url = self.url()
        if request_url is None:
            Base.log(self, message="HttpOperation " + "request : "
                                   + " \error : \n url cannot be None", message_type=MESSAGE_TYPE.ERROR)
            return
        try:
            http = urllib3.PoolManager()
            resp = http.request(http_method, request_url)
            data_string = resp.data.decode('utf-8')
            Base.log(self, message="HttpOperation " + "request : " + str(request_url) + " \nresponse : \n" + data_string,
                     message_type=MESSAGE_TYPE.INFO)
            self._response = data_string
            return self
        except urllib3.exceptions.HTTPError as e:
            Base.log(self, message="HttpOperation " + "request : "
                                   + " \HTTPError : \n " + str(e.code), message_type=MESSAGE_TYPE.ERROR)
        except urllib3.exceptions.RequestError as e:
            Base.log(self, message="HttpOperation request : URLError : " + str(e.reason),
                     message_type=MESSAGE_TYPE.ERROR)
        except Exception as e:
            Base.log(self, message="HttpOperation " + "request : "
                                   + " \generic exception : \n " + str(e), message_type=MESSAGE_TYPE.ERROR)
        self._response = None
        return None

    def jsonParse(self):
        if self._response is None or not str(self._response).strip():
            return None
        jsonData = json.loads(self._response)
        return jsonData

    def fetch(self, url=None, httpMethod="GET"):
        request_url = None
        if url is not None:
            request_url = str(url)
        else:
            request_url = self.url()
        if request_url is None:
            Base.log(self, message="HttpOperation " + "request : "
                                   + " \error : \n url cannot be None", message_type=MESSAGE_TYPE.ERROR)
            return
        try:
            http = urllib3.PoolManager()
            resp = http.request(httpMethod, request_url)
            data_string = resp.data.decode('utf-8')
            Base.log(self, message="HttpOperation " + "request : " + str(request_url) + " \nresponse : \n" + data_string,
                     message_type=MESSAGE_TYPE.INFO)
            return data_string
        except urllib3.exceptions.HTTPError as e:
            Base.log(self, message="HttpOperation " + "request : "
                                   + " \HTTPError : \n " + str(e.code), message_type=MESSAGE_TYPE.ERROR)
        except urllib3.exceptions.RequestError as e:
            Base.log(self, message="HttpOperation request : URLError : \n " + str(e.reason),
                     message_type=MESSAGE_TYPE.ERROR)
        except Exception as e:
            Base.log(self, message="HttpOperation " + "request : "
                                   + " \generic exception : \n " + str(e), message_type=MESSAGE_TYPE.ERROR)
        return None



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
## test
############################################################
## Author: Umut Boz
## Copyright (c) 2020, OneframeMobile, KoçSistem
## Email: oneframemobile@gmail.com
############################################################
## Version: 0.1.0
############################################################



from lib.enums import MessageType

from lib.enums import CodeLine
from lib.log import Log
from lib.fileOperation import FileOperation
from lib.environment import Environment


MESSAGE = MessageType()

CODE = CodeLine()

path = "/"
fileName = "test.swift"
#eger bir path belirlenmis ise
#op = FileOperation("/Users/umut/Desktop/Architecture/CodeGenerationCore/lib")
#run path kullanılmak isteniyorsa
op = FileOperation()

#get content of file with relative Path
#print(op.getFileContentWithPath(filePath=path + CODE.SLASH + fileName))

#get content of file with fileName on the current path
#print(op.getFileContent(fileName="lib/test.py"))

#get content of file with fileName on the relative path
#print(op.getFileContent(filePath = "/lib/test.py"))

#create file with relative path 
#op.create(filePath=filePath,content="hello")

#path param ile verilen path üzerine dosya oluşturulur.
#op.createFile(path="lib",fileName="test.swift",content="hello")


#init de verilen default path üzerine klasör oluşturulur.
#op.createFolder(folderName="hello/1")

#path is valid
#print(op.isExist("/Users/umut/Desktop/Architecture/CodeGenerationCore/lib"))

#append file add content
#op.appendFile(fileName="test.swift",content="\nworld")


#loglar kapali artik
#Environment.Shared().online()

print(type(Environment.Shared().online()))

#remove file
#op.removeFile(fileName=fileName)
#op.createFile(fileName=fileName, content="hello")


#print(MESSAGE.ERROR)
#print(DEV_ENV.LOCAL)
#print(CODE.SLASH)


#log samples
#Log.i(message=MESSAGE.INFO)
#Log.s(MESSAGE.SUCCESS)
#Log.e(MESSAGE.ERROR)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# TemplateFile
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################


# Owned
from codegenlib.abstract import Base
from codegenlib.enums import MESSAGE_TYPE


class TemplateFile(Base):
    name = ""
    outputFile = ""
    dict = None
    isChildTemplate = False
    # subTemplates = []
    parentMustache = ""
    childTemplateFiles = []
    content = ""

    def __init__(self, name, dict, output_file, is_child_template=False, parent_mustache="", child_template_files = [], content = ""):
        Base.__init__(self)
        self.name = name
        self.dict = dict
        self.outputFile = output_file
        self.isChildTemplate = is_child_template
        self.parentMustache = parent_mustache
        self.childTemplateFiles = child_template_files
        self.content = content



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# Abstract
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################
from codegenlib.enums import DevelopmentEnvironment
from codegenlib.environment import Environment
from codegenlib.singleton import Singleton
from codegenlib.enums import MESSAGE_TYPE
from codegenlib.log import Log


class Base():
    def __init__(self):
        if type(self) is Base:
            raise Exception('Base is an abstract class and cannot be instantiated directly')
        # Any initialization code
        if Environment.Shared().current() == DevelopmentEnvironment().DEBUG:
            print('In the __init__  method of the Base class' + ' call child from : ' + self.toString())

    def log(self, message, message_type):
        #print("base'den " + str(Environment.Shared().current()))
        # ÇALIŞMA ORTAMI FARKET meksizin tüm hatalar(exceptions) gösterilir.
        if message_type == MESSAGE_TYPE.ERROR:
            Log.e(message=message)
        else:
            # loglar ise sadece debug modda gösterilir
            if Environment.Shared().current() == DevelopmentEnvironment().DEBUG:
                print("base log çalıştı")
                Log.i(message=message)
            '''
            else:
                print("base log çalışmadı")
            '''
            
    def toString(self):
        return self.__class__.__name__



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# Enums
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################

from codegenlib.constantType import constant
#from constantType import constant


# choose these enums for user feedback


class MessageType(object):
    @constant
    def INFO():
        return "INFO"

    @constant
    def ERROR():
        return "ERROR"

    @constant
    def SUCCESS():
        return "SUCCESS"


# TemplateFile choose what development environment you want
# github raw templates or local template files


class DevelopmentEnvironment(object):
    @constant
    def LOCAL():
        return "LOCAL"

    @constant
    def ONLINE():
        return "ONLINE"

    @constant
    def DEBUG():
        return "DEBUG"


# choose these enums for code syntax


class CodeLine(object):
    @constant
    def NEWLINE():
        return "\n"

    @constant
    def SPACE_AFTER():
        return "    "

    @constant
    def SLASH():
        return "/"

    @constant
    def DOT():
        return "."
    
    @constant
    def TAB():
        return "\t"


# choose these Mustache enums for code syntax


class Mustache(object):
    @constant
    def PARENT():
        return "PARENT"

    @constant
    def SUB():
        return "SUB"

    @constant
    def LEFT_BRACKET():
        return "{"

    @constant
    def RIGHT_BRACKET():
        return "}"


CODING = CodeLine()
MESSAGE_TYPE = MessageType()
MUSTACHE = Mustache()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# Singleton
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################


class Singleton:
    def __init__(self, cls):
        self._cls = cls

    def Shared(self):
        try:
            return self._instance
        except AttributeError:
            self._instance = self._cls()
            return self._instance

    def __call__(self):
        raise TypeError('Singletons must be accessed through `Instance()`.')

    def __instancecheck__(self, inst):
        return isinstance(inst, self._cls)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# TemplateStreaming
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.6.0
############################################################


# Built-in/Generic Imports
import os
import sys
import re

# Own modules

from codegenlib.abstract import Base
from codegenlib.enums import MessageType
from codegenlib.enums import CODING
from codegenlib.enums import MUSTACHE
from codegenlib.fileOperation import FileOperation
from codegenlib.templateFile import TemplateFile
from codegenlib.templateModule import TemplateModule
#from codegenlib.httpOperation import HttpOperation
from codegenlib.parser import Parser
from codegenlib.enums import MESSAGE_TYPE


class TemplateStreaming(Base):
    global httpOp
    global fileOp
    global child_all_content
    global tabCount
    templateModule = None
    isCreationFile = True
    enableLog = False

    def __init__(self, template_module, enable_log=False):
        Base.__init__(self)
        #self.httpOp = HttpOperation()
        self.fileOp = FileOperation()
        self.templateModule = template_module
        self.enableLog = enable_log
        self.child_all_content = ""

    def execute(self):
        # search all template files
        # if it has output directory in module, it is generating
        if len(self.templateModule.templateFiles) > 0 and str(self.templateModule.outputDirectory).strip() != '':
            if self.fileOp.isExist(
                    self.templateModule.getOutputDirectoryPath()) and self.templateModule.isAppendOutputPath:
                # TODO : delete folder
                self.fileOp.removeRecursively(folder_path=self.templateModule.getOutputDirectoryPath())
                module_directory_path = self.templateModule.getModuleOutputPath()
                #directory_path = self.fileOp.createNewPath(self.templateModule.outputRootPath,
                #                                           self.templateModule.outputDirectory)
                self.fileOp.createFolderWithoutPath(module_directory_path)

            elif self.fileOp.isExist(
                    self.templateModule.getOutputDirectoryPath()) and not self.templateModule.isAppendOutputPath:
                # folder has already
                Base.log(self,
                         message="This Folder already exists \n" + self.templateModule.getOutputDirectoryPath() +
                                 "\n if you renew re-creation this folder, you should set 'isAppendOutputPath' field "
                                 "to True. But all files will be deleted",
                         message_type=MESSAGE_TYPE.INFO)
            else:
                #module_directory_path = self.templateModule.getModuleOutputPath()
                module_directory_path = self.templateModule.getGeneratingOutputPath()
                #directory_path = self.fileOp.createNewPath(self.templateModule.outputRootPath + CODING.SLASH + self.getModulePath(),
                #                                           self.templateModule.outputDirectory)
                self.fileOp.createFolderWithoutPath(module_directory_path)

        # initialize template folders
        self.templateModule.initializeTemplateFolder()

        for t_file in self.templateModule.templateFiles:
            # print(t_file.name)
            # do file has own child files?
            if len(t_file.childTemplateFiles) > 0:
                child_loop_all_content = ''
                if t_file.content != '':
                    child_loop_all_content = t_file.content
                else:
                    child_loop_all_content = self.getOwnChildContent(t_file)

                if self.enableLog:
                    print(child_loop_all_content)
                # generate output file
                if str(t_file.outputFile).strip():
                    #module_directory_path = self.templateModule.getModuleOutputPath()
                    module_directory_path = self.templateModule.getGeneratingOutputPath()
                    if self.enableLog:
                        print("output: " + module_directory_path)
                    self.fileOp.create(file_path = module_directory_path + CODING.SLASH + t_file.outputFile, content=child_loop_all_content)

            else :
                replaced_template_content = ''
                if t_file.content != '':
                    replaced_template_content = t_file.content
                else:
                # only work parent files
                # get filter Node return tuple (x,y)
                    has_parent_key, parent_objects = self.filterParentNode(t_file.dict)
                    if has_parent_key:
                        # loop parentObject
                        child_content = ""
                        for parent in parent_objects:
                            # findChildFile By ParentObjects
                            founded_files = self.findTemplateFileByKey(mustache_key=parent[0], is_child=True)
                            # find hasChild File
                            if len(founded_files) > 0:
                                for child_file in founded_files:
                                    # get Child Content
                                    # print(childFile)
                                    loop_child_content = self.fileContent(file=child_file)
                                    loop_child_content = Parser.string_multiple_replace(loop_child_content,
                                                                                        self.dictToMustache(
                                                                                            child_file.dict))
                                    # print(loopChildContent)
                                    child_content = child_content + CODING.NEWLINE + loop_child_content

                        t_file.dict[parent[0]] = MUSTACHE.LEFT_BRACKET + MUSTACHE.LEFT_BRACKET + parent[0] + MUSTACHE.RIGHT_BRACKET + MUSTACHE.RIGHT_BRACKET + child_content
                        # print(t_file.dict[parent[0]])
                        # print(t_file.dict)

                    content = self.fileOp.readContent(file_path=self.getModulePath() + CODING.SLASH + t_file.name)
                    replaced_template_content = Parser.string_multiple_replace(content, self.dictToMustache(t_file.dict))
                if self.enableLog:
                    print(replaced_template_content)
                # generate output file
                if str(t_file.outputFile).strip():
                    #module_directory_path = self.templateModule.getModuleOutputPath()
                    module_directory_path = self.templateModule.getGeneratingOutputPath()
                    if self.enableLog:
                        print("output: " + module_directory_path)
                    self.fileOp.create(file_path = module_directory_path + CODING.SLASH + t_file.outputFile, content=replaced_template_content)

    
    # recursive collect child content
    def getOwnChildContent(self, file, previous_content = None):
        if self.enableLog:
            print("t", file.name) 
        content = self.fileContent(file=file)
        if previous_content != None:
            content = previous_content
        else:
            self.child_all_content = ""
            self.tabCount = 0
        
        has_parent_key, parent_objects = self.filterParentNode(file.dict)
        #has parent key
        if has_parent_key:
            child_content = ""
            #has child files
            
            if len(file.childTemplateFiles) > 0:
                self.tabCount  = self.tabCount  + 1
                for child_file in file.childTemplateFiles:
                    has_did_it_match_parent_mustache = self.didItMatchParentMustache(child_file=child_file,parent_objects=parent_objects)
                    if has_did_it_match_parent_mustache:
                        child_mustache_content = self.fileContent(file=child_file)
                        #print(child_content)
                        # tabbed string development
                        tab_string_started_content = ""
                        #print(tab_string_started_content)
                        for i in range(self.tabCount):
                            tab_string_started_content = CODING.TAB + tab_string_started_content 
                        
                        tabbed_child_content = ""
                        for line in child_mustache_content.splitlines():
                            tabbed_child_content = tabbed_child_content + tab_string_started_content + line + CODING.NEWLINE

                        # replace parent to child content
                        # replaced_dictionary
                        child_content_output = Parser.string_multiple_replace(tabbed_child_content,self.dictToMustache(child_file.dict))

                        child_content += CODING.NEWLINE + child_content_output
                
                replaced_dictionary = self.replaceDictToChildContent(parent_dict=file.dict, parent_objects=parent_objects,child_file_content=child_content, child_file=child_file)
                loop_child_content = Parser.string_multiple_replace(content,self.dictToMustache(replaced_dictionary))
                       
                self.getOwnChildContent(file, previous_content = loop_child_content)
            else:
                # only work parent files
                # get filter Node return tuple (x,y)
                has_parent_key, parent_objects = self.filterParentNode(file.dict)
                if has_parent_key:
                    child_content = self.fileContent(file=file)
                    tab_string_started_content = ""
                    #print(tab_string_started_content)
                    for i in range(self.tabCount):
                        tab_string_started_content = CODING.TAB + tab_string_started_content 
                        
                    tabbed_child_content = ""
                    for line in child_content.splitlines():
                        tabbed_child_content = tabbed_child_content + tab_string_started_content + line + CODING.NEWLINE
        
                    replaced_dictionary = self.replaceDictToChildContent(parent_dict=file.dict, parent_objects=parent_objects,child_file_content=tabbed_child_content, child_file=file)
                    loop_child_content = Parser.string_multiple_replace(content,self.dictToMustache(replaced_dictionary))
                    self.child_all_content = loop_child_content
                    return self.child_all_content
        else:
            # fill content
            self.child_all_content = Parser.string_multiple_replace(content,self.dictToMustache(file.dict))
            if self.enableLog:
                print(self.child_all_content)
        
        return self.child_all_content


    def didItMatchParentMustache(self,parent_objects,child_file):
        result = False
        for parent in parent_objects:
            if parent[0] == child_file.parentMustache:
                result = True
        return result

    def replaceDictToChildContent(self,parent_dict,parent_objects,child_file_content,child_file):
        result_dict = parent_dict
        #parent_dict["extension_parent_add"] = child_file_content
        for parent in parent_objects:
            if parent[0] == child_file.parentMustache:
                result_dict[child_file.parentMustache] = child_file_content
        return result_dict  
          
    def getModulePath(self):
        '''
        module_path = self.fileOp.createNewPath(
            pathLocate="..",
            folderName="modules/" + self.templateModule.name
        )
        '''
        return self.templateModule.getModulePath()

    def findTemplateFileByKey(self, mustache_key, is_child):
        found_files = []  # type: List[TemplateFile]
        for tFile in self.templateModule.templateFiles:
            if tFile.isChildTemplate == is_child and self.findChildMustachFilter(file=tFile, mustache_key=mustache_key):
                found_files.append(tFile)
        return found_files
    

    def fileContent(self, file):
        content = self.fileOp.readContent(file_path=self.getModulePath() + CODING.SLASH + file.name)
        return content

    def findChildMustachFilter(self, file, mustache_key):
        # print(file.name, mustacheKey)
        if file.parentMustache == mustache_key:
            return True
        else:
            return False

    def findMustacheFilter(self, file, mustache_key):
        # print(file.name, mustacheKey)
        find_mustache_filter = lambda x: x[0] == mustache_key
        filter_output = filter(find_mustache_filter, file.dict.items())
        # print(filter_output)
        return len(list(filter_output)) > 0 if True else False

    def filterParentNode(self, dict):
        find_parent_filter = lambda x: x[1] == MUSTACHE.PARENT
        if dict is None:
            return False, ""
        filter_output = filter(find_parent_filter, dict.items())
        return (len(list(filter_output)) > 0 if True else False), filter_output


    def dictToMustache(self, dictionary):
        new_dict = dict()
        if dictionary is None:
            return new_dict
        for key in dictionary.keys():
            new_key = MUSTACHE.LEFT_BRACKET + MUSTACHE.LEFT_BRACKET + key + MUSTACHE.RIGHT_BRACKET + MUSTACHE.RIGHT_BRACKET
            new_dict[new_key] = dictionary[key]
        return new_dict
    
    def tabbedContent(self,content, tab_index):
        tab_started_string = ""
        for i in range(tab_index):
            tab_started_string = CODING.TAB + tab_started_string 
                        
        tabbed_content = ""
        for line in content.splitlines():
            tabbed_content = tabbed_content + tab_started_string + line + CODING.NEWLINE
        
        return tabbed_content
        



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
#  test http py 2.7
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################
from lib.enums import MessageType
from lib.enums import CodeLine
from lib.log import Log
from lib.environment import Environment
from lib.httpOperation import HttpOperation

MESSAGE = MessageType()

CODE = CodeLine()

# close log
Environment.Shared().online()

url = "https://petstore.swagger.io/v2/swagger.json"

op = HttpOperation()
jsonData = op.request(url=url).jsonParse()

op2 = HttpOperation(url=url)
jsonData = op2.request().jsonParse()

op3 = HttpOperation()
responseString = op3.fetch(url=url)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# TemplateModule
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.6.0
############################################################

import os
import sys
# Owned
from codegenlib.abstract import Base
from codegenlib.fileOperation import FileOperation
from codegenlib.enums import CODING
from codegenlib.enums import MESSAGE_TYPE

pathname = os.getcwd()

class TemplateModule(Base):
    name = ""
    templateFiles = []
    outputRootPath = ""
    outputDirectory = ""
    isAppendOutputPath = False
    isGenerateOutPutFullPath = False
    mustacheFolder = ""
    templateFolders = []
    fileOp = FileOperation()

    def __init__(self, name, templates_files, mustache_folder = '', template_folders=[], output_root_path=pathname):
        Base.__init__(self)

        self.name = name
        self.templateFiles = templates_files
        self.outputRootPath = output_root_path
        self.templateFolders = template_folders
        self.mustacheFolder = mustache_folder

    def getOutputDirectoryPath(self):
        return self.outputRootPath + CODING.SLASH + self.getModulePath() + CODING.SLASH + self.outputDirectory
    
    def getModulePath(self):
        module_path = ''
        '''
        module_path = self.fileOp.createNewPath(
            pathLocate="..",
            folderName="modules/" + self.name
        )
        '''
        if self.mustacheFolder != '':
            module_path = pathname + CODING.SLASH + self.mustacheFolder
        
        if module_path != '':
            # Check if last character is 't'
            if str(module_path).endswith(CODING.SLASH):
                module_path = module_path + self.name
            else:
                module_path = module_path + CODING.SLASH + self.name
        else:
            module_path = pathname + CODING.SLASH + self.name
        
        return module_path

    def getModuleOutputPath(self):
        module_directory_path = self.outputRootPath + CODING.SLASH + "modules" +  CODING.SLASH  + self.name + CODING.SLASH  + self.outputDirectory
        return module_directory_path
    
    def getGeneratingOutputPath(self):
        module_directory_path = os.getcwd()
        if self.isGenerateOutPutFullPath:
            module_directory_path = self.outputDirectory
        else:
            if self.outputDirectory != '':
                module_directory_path += CODING.SLASH + self.outputDirectory
        return module_directory_path
    
    def initializeTemplateFolder(self):
        for t_folder in self.templateFolders:
            t_folder_source_full_path = self.outputRootPath + CODING.SLASH + t_folder.source
            t_folder_output_full_path = self.getOutputDirectoryPath() + CODING.SLASH + t_folder.outputPath
            # template folder is exist ?
            if not self.fileOp.isExist(t_folder_output_full_path):
                self.fileOp.createFolderWithoutPath(t_folder_output_full_path)
            # source template is online ?
            if t_folder.isOnline:
                root_github_module_url = "https://raw.githubusercontent.com/umutboz/code-gen-lib/master/modules" + CODING.SLASH + self.name
                # https://raw.githubusercontent.com/umutboz/code-gen-lib/master/modules/oneframe-ios-api-manager/models/ApplicationRole.swift
                t_folder_source_full_path =  root_github_module_url
                print(root_github_module_url)
            else:
                if self.fileOp.isExist(t_folder_source_full_path):
                    source_files = self.fileOp.files(t_folder_source_full_path)
                    for s_file in source_files:
                        source = t_folder_source_full_path + CODING.SLASH + s_file
                        destination = t_folder_output_full_path + CODING.SLASH + s_file
                        # print("source: ", source)
                        os.system("cp " + source + " " + destination)

            print("target: ", t_folder_output_full_path)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# parser
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################

# Built-in/Generic Imports

import re
import json
import os
import sys

# Owned
from codegenlib.abstract import Base
from codegenlib.templateModule import TemplateModule
from codegenlib.templateFile import TemplateFile
from codegenlib.templateFolder import TemplateFolder


class Parser(Base):
    def __init__(self):
        Base.__init__(self)

    def jsonToTemplateModule(json_file):
        module = TemplateModule(name="", templates_files=[])
        with open(json_file, 'r') as json_file:
            try:
                json_decode=json.load(json_file)
                json_decode_dump = json.dumps(json_decode)
                for tempFile in json_decode["module"]["templateFiles"]:
                    name = str(tempFile["name"])
                    dictionary = None
                    output_file = None
                    is_child_template = False
                    parent_mustache = ""
                    if not (tempFile.get('dict') is None):
                        dictionary = eval(json.dumps(tempFile["dict"]))
                    if not (tempFile.get('outputFile') is None):
                        output_file = str(tempFile["outputFile"])
                    if not (tempFile.get('isChildTemplate') is None):
                        is_child_template = tempFile.get('isChildTemplate')
                    if not (tempFile.get('parentMustache') is None):
                        parent_mustache = str(tempFile.get('parentMustache'))

                    module.templateFiles.append(TemplateFile(
                        name=name,
                        dict=dictionary,
                        output_file=output_file,
                        is_child_template=is_child_template,
                        parent_mustache=parent_mustache))

                # template folder generate
                if not (json_decode.get('module').get('templateFolders') is None):
                    for tempFolder in json_decode["module"]["templateFolders"]:
                        source = ""
                        output_path = ""
                        is_online = False
                        if not (tempFolder.get('source') is None):
                            source = eval(json.dumps(tempFolder["source"]))
                        if not (tempFolder.get('outputPath') is None):
                            output_path = str(tempFolder["outputPath"])
                        if not (tempFolder.get('isOnline') is None):
                            is_online = tempFolder.get('isOnline')

                    module.templateFolders.append(TemplateFolder(
                        source=source,
                        output_path=output_path,
                        is_online=is_online
                    ))

                module.name = str(json_decode["module"]["name"])
            except OSError:
                print ("Could not open/read file:", json_file)
                json_file.seek(0)
        return module

    def string_multiple_replace(string, replacement_dict):
        if len(replacement_dict) == 0:
            return string
        pattern = re.compile("|".join([re.escape(k) for k in sorted(replacement_dict, key=len, reverse=True)]), flags=re.DOTALL)
        return pattern.sub(lambda x: replacement_dict[x.group(0)], string)

    def string_multiple_replace_with_child(string, replacement_dict):
        if len(replacement_dict) == 0:
            return string
        pattern = re.compile("|".join([re.escape(k) for k in sorted(replacement_dict, key=len, reverse=True)]), flags=re.DOTALL)
        return pattern.sub(lambda x: replacement_dict[x.group(0)], string)
    

    string_multiple_replace = staticmethod(string_multiple_replace)
    jsonToTemplateModule = staticmethod(jsonToTemplateModule)
    string_multiple_replace_with_child = staticmethod(string_multiple_replace_with_child)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# Environment
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################

# Built-in/Generic Imports
# from __future__ import annotations
# rom typing import Optional

# Own modules
from codegenlib.enums import DevelopmentEnvironment
from codegenlib.singleton import Singleton


@Singleton
class Environment(object):
    global env
    env = DevelopmentEnvironment().DEBUG

    def debug(self):
        global env
        env = DevelopmentEnvironment().DEBUG

    def local(self):
        global env
        env = DevelopmentEnvironment().LOCAL

    def online(self):
        global env
        env = DevelopmentEnvironment().ONLINE

    def current(self):
        global env
        return env



import unittest

from src.codegenlib.templateModule import TemplateModule

testModule = TemplateModule(
    name="test-module",
    templates_files=[]
    )

class TestSimple(unittest.TestCase):
    

    def test_module_path(self):
        path = testModule.getModulePath()
        print(path)
        self.assertEqual(testModule.name, "test-module")


if __name__ == '__main__':
    unittest.main()


__version__ = "0.6.2"

import os
import sys
import re
import shutil
import json
#import urllib2
import ssl
#import urllib3

from . import constantType
from .constantType import constant
from . import enums
from . import environment
from . import singleton
from .log import Logger,Log
from .enums import MESSAGE_TYPE,MUSTACHE,CODING
from .enums import DevelopmentEnvironment
from .environment import Environment
from .singleton import Singleton
from .abstract import Base
from .templateFile import TemplateFile
from .fileOperation import FileOperation
from .templateModule import TemplateModule

from .templateFolder import TemplateFolder

#from .httpOperation import HttpOperation
#from .httpOperation3 import HttpOperation3
from .parser import Parser


from .templateStreaming import TemplateStreaming





#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# Log
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################


class Logger:
    """This class now shares all its attributes among its various instances"""

    # This essentially makes the singleton objects an object-oriented global variable
    def __init__(self):
        pass

    def e(self, message):
        print ("\x1b[6;30;41m" + message + "\x1b[0m")

    def i(self, message):
        print ("\x1b[7;37;40m" + message + "\x1b[0m")

    def s(self, message):
        print ("\x1b[6;30;42m" + message + "\x1b[0m")
    
    def w(self, message):
        print ("\x1b[6;30;43m" + message + "\x1b[0m")


Log = Logger()



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='codegenlib',
    author='Umut Boz',
    author_email='umut.boz@outlook.com',
    version="0.6.2",
    description='Code Generation library written by python. can use bash script, can be extend python code, can use mustache files or can use any string content for any code generation structure.',
    keywords='code generation, file generation, pypi, package',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/umutboz/code-gen-lib',
    project_urls={
        'Documentation': 'https://github.com/umutboz/code-gen-lib',
        'Bug Reports':
        'https://github.com/umutboz/code-gen-lib/issues',
        'Source Code': 'https://github.com/umutboz/code-gen-lib'
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=2.7',
    # install_requires=['Pillow'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
## FileOperation
############################################################
## Author: Umut Boz
## Copyright (c) 2020, OneframeMobile, KoçSistem
## Email: oneframemobile@gmail.com
############################################################
## Version: 0.1.0
############################################################

# Built-in/Generic Imports
import os
import sys
import shutil

# Own modules
from codegenlib.abstract import Base
from codegenlib.enums import CODING
from codegenlib.enums import MESSAGE_TYPE


class FileOperation(Base):
    _path = ""

    def __init__(self, path=None):
        Base.__init__(self)
        self._path = path

    def getPath(self):
        # path has not chars and is none
        if self._path is None or not str(self._path).strip():
            return os.getcwd()
        else:
            return self._path

    def create(self, file_path, content):
        try:
            file_path = open(file_path, "w")
            file_path.write(content)
            file_path.close()
            Base.log(self, message="FileOperation " + "create : " + str(file_path) + " \ncontent : \n" + content,
                     message_type=MESSAGE_TYPE.INFO)
        except OSError as e:
            Base.log(self, message="FileOperation " + "create : "
                                   + " \error : \n" + str(e), message_type=MESSAGE_TYPE.ERROR)

    def createFile(self, file_name, content):
        file_path = self.getPath() + CODING.SLASH + file_name
        try:
            file_path = open(file_path, "w")
            file_path.write(content)
            file_path.close()
            Base.log(self, message="FileOperation " + "createFile : " +
                                   str(file_path) + " \ncontent : \n" + content, message_type=MESSAGE_TYPE.INFO)
        except OSError as e:
            Base.log(self, message="FileOperation " + "createFile : "
                                   + " \error : \n" + str(e), message_type=MESSAGE_TYPE.ERROR)

    def createFolder(self, folder_name):
        folder_path = self.getPath() + CODING.SLASH + folder_name
        try:
            if not os.path.isdir(folder_path):
                os.makedirs(folder_path)
                Base.log(self, message="FileOperation " + "createFolder : " +
                                       folder_path + "\n", message_type=MESSAGE_TYPE.INFO)
            else:
                Base.log(self, message="FileOperation " + "createFolder : " +
                                       folder_path + "\n already path", message_type=MESSAGE_TYPE.INFO)
        except OSError as e:
            Base.log(self, message="FileOperation " + "createFileWithPath : " + " \error : \n" +
                                   str(e), message_type=MESSAGE_TYPE.ERROR)

    def createFolderWithoutPath(self, folder_name):
        folder_path = folder_name
        try:
            if not os.path.isdir(folder_path):
                os.makedirs(folder_path)
                Base.log(self, message="FileOperation " + "createFolder : " +
                                       folder_path + "\n", message_type=MESSAGE_TYPE.INFO)
            else:
                Base.log(self, message="FileOperation " + "createFolder : " +
                                       folder_path + "\n already path", message_type=MESSAGE_TYPE.INFO)
        except OSError as e:
            Base.log(self, message="FileOperation " + "createFileWithPath : " + " \error : \n" +
                                   str(e), message_type=MESSAGE_TYPE.ERROR)

    def appendFile(self, file_name, content, is_truncate=False):
        file_path = self.getPath() + CODING.SLASH + file_name
        try:
            with open(file_path, "a+") as f:
                # f.seek(0)
                if is_truncate:
                    f.truncate()
                f.write(content)
                f.close()
                Base.log(self, message="FileOperation " + "appendFile : " +
                                       file_path + "\n", message_type=MESSAGE_TYPE.INFO)
        except OSError as e:
            Base.log(self, message="FileOperation " + "appendFile : \error : \n" +
                                   str(e), message_type=MESSAGE_TYPE.ERROR)

    # has path valid and exist return true
    def isExist(self, path):
        if os.path.exists(path):
            return True
        else:
            return False

    # for content of file with filePath
    def readContent(self, file_path):
        global content
        if self.isExist(file_path):
            with open(file_path, "r") as data:
                content = data.read()
            return content
        else:
            Base.log(self, message="FileOperation " + "readContent : " + file_path +
                                   "\n has not found file", message_type=MESSAGE_TYPE.INFO)
            return ""

    # for content of file with fileName
    def getFileContent(self, file_name):
        file_path = self.getPath() + CODING.SLASH + file_name
        return self.readContent(filePath=file_path)

    # for remove file with filePath
    def remove(self, file_path):
        if self.isExist(file_path):
            os.remove(file_path)
            Base.log(self, message="FileOperation " + "remove : " + file_path +
                                   "\n file was removed", message_type=MESSAGE_TYPE.INFO)
        else:
            Base.log(self, message="FileOperation " + "remove : " + file_path +
                                   "\n has not found file", message_type=MESSAGE_TYPE.INFO)
            return ""

    def removeRecursively(self, folder_path):
        if self.isExist(folder_path):
            shutil.rmtree(folder_path)

    # for remove file with fileName
    def removeFile(self, file_name):
        file_path = self.getPath() + CODING.SLASH + file_name
        self.remove(file_path)

    def files(self, directory_path):
        if self.isExist(path=directory_path):
            return os.listdir(directory_path)
        else:
            return []

    def aboveNewPath(self, path):
        return os.path.abspath(os.path.join(os.path.dirname(__file__), '..', path))

    def belowNewPath(self, path):
        return os.path.abspath(os.path.join(os.path.dirname(__file__), '', path))

    def createNewPath(self, pathLocate, folderName):
        return os.path.abspath(os.path.join(os.path.dirname(__file__), pathLocate, folderName))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
# TemplateFolder
############################################################
# Author: Umut Boz
# Copyright (c) 2020, OneframeMobile, KoçSistem
# Email: oneframemobile@gmail.com
############################################################
# Version: 0.1.0
############################################################


# Owned
from codegenlib.abstract import Base
from codegenlib.enums import MESSAGE_TYPE


class TemplateFolder(Base):
    # root templateStreaming file path + append your source path
    source = ""
    # root templateModule path + append your target path
    outputPath = ""
    isOnline = False

    def __init__(self, source, output_path, is_online=False):
        Base.__init__(self)
        self.source = source
        self.outputPath = output_path
        self.isOnline = is_online
